@@ -2,7 +2,7 @@ from rest_framework.authtoken.models import Token
 from django.contrib.auth.models import AnonymousUser
 
 
-def channels_authentication(scope):
+def set_user(scope):
     kwargs = scope['url_route']['kwargs']
     if 'token' in kwargs.keys():
         token = kwargs['token']
